@@ -181,7 +181,7 @@ class MyWhatify:
         base_url = base_url[:-1]
 
         ret_json = cls.base_api(url=base_url, method=api_method, headers=cls.magento_headers, body=body)
-        retval = pd.DataFrame.from_dict(ret_json['data'], orient='columns')
+        retval = pd.DataFrame.from_dict(ret_json['data']['rows'], orient='columns')
         return retval
 
     #############################
